@@ -3,8 +3,8 @@
 ;; Author: Yad Tahir <yad at ieee.org>
 ;; URL: https://github.com/yad-tahir/evil-insert-plus
 ;; Package-Requires: ((emacs "24.4") (evil "1.14.0"))
-;; Package-Version: 20260119.926
-;; Package-Revision: d264c13585f3
+;; Package-Version: 20260127.1015
+;; Package-Revision: d584ed3ea2a4
 ;; Keywords: emulations, textvim, editing
 
 ;; This file is not part of GNU Emacs.
@@ -85,7 +85,7 @@ IS-APPEND determines if the operation is an append or insert."
   (interactive "<R><c>") ; <R> for range and type, <c> for count
   (let ((vcount (evil-insert-plus--vcount)))
     (cond
-     ((eq type 'line)
+     ((memq type '(line screen-line))
       ;; visual-goto-line motions - e.g. `evil-goto-first-line'
       (unless (or (evil-visual-state-p)
                   (eq evil-this-motion 'evil-line-or-visual-line))
@@ -105,7 +105,7 @@ IS-APPEND determines if the operation is an append or insert."
   (interactive "<R><c>") ; <R> for range and type, <c> for count
   (let ((vcount (evil-insert-plus--vcount)))
     (cond
-     ((eq type 'line)
+     ((memq type '(line screen-line))
       ;; visual-goto-line motions - e.g. `evil-goto-line'
       (unless (or (evil-visual-state-p)
                   (eq evil-this-motion 'evil-line-or-visual-line))
